@@ -109,21 +109,26 @@ def _NewFrame(
     return output
 
 
-def _AdjustFrameGrid(
-    figure: backend_figure_t,
-    shape: list[int],
-    frames: list[frame_t],
-    locations: list[tuple[int, int]],
-    /,
-) -> None:
+def _AdjustLayout(figure: figure_t, /) -> None:
     """"""
-    if frames.__len__() < 2:
+    raw_figure = figure.backend
+
+    if figure.title is not None:
+        raw_figure.suptitle(figure.title)
+    for frame in figure.frames:
+        if frame.title is not None:
+            frame.backend.set_title(frame.title)
+        for plot in frame.plots:
+            if plot.title is not None:
+                plot.backend.set_label(plot.title)
+
+    if figure.frames.__len__() < 2:
         return
 
-    grid_spec = grid_spec_t(*shape, figure=figure)
-    bottoms, tops, lefts, rights = grid_spec.get_grid_positions(figure)
+    grid_spec = grid_spec_t(*figure.shape, figure=raw_figure)
+    bottoms, tops, lefts, rights = grid_spec.get_grid_positions(raw_figure)
 
-    for frame, (row, col) in zip(frames, locations):
+    for frame, (row, col) in zip(figure.frames, figure.locations):
         left, bottom, width, height = (
             lefts[col],
             bottoms[row],
@@ -140,7 +145,6 @@ def _Show(
     """"""
     raw = figure.backend
 
-    _AdjustFrameGrid(raw, figure.shape, figure.frames, figure.locations)
     raw.show()
 
     event_manager = raw.canvas
@@ -213,7 +217,7 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFigure": staticmethod(NewBackendFigure),
         "NewBackendFrame": staticmethod(_NewFrame),
-        "AdjustFrameGrid": staticmethod(_AdjustFrameGrid),
+        "AdjustLayout": _AdjustLayout,
         "BackendShow": _Show,
         "BackendSetProperty": staticmethod(_SetProperty),
         "BackendProperty": staticmethod(_Property),
