@@ -301,7 +301,7 @@ PLOT_DESCRIPTION = {
         (2, 3),
     ),
     plot_e.TEXT: (
-        "Text annotation in two or three dimensions",
+        "Text annotation",
         "Text annotation in two or three dimensions.\n"
         "Required argument: TEXT, and X, Y, and Z position (depending on the dimension).",
         (2, 3),
